{% extends "registration/base.html" %}

{% load i18n %}


{% block title %}{% trans "Log In" %}{% endblock title %}

{% block page_main_title %}{% trans "Log In" %}{% endblock page_main_title %}

{% block content %}
    {% include "registration/login_form.html" %}
{% endblock content %}
