{% extends "registration/base.html" %}

{% load crispy_forms_tags %}
{% load i18n %}


{% block title %}{% trans "Password Reset" %}{% endblock title %}

{% block page_main_title %}{% trans "Password Reset" %}{% endblock page_main_title %}

{% block content %}
    <p>{% trans "Forgotten your password? Enter your e-mail address below, and we'll e-mail instructions for setting a new one." %}</p>

    {% block form %}
        <form class="{% block form_class %}{% endblock form_class %}" action="" method="post">
            {% csrf_token %}

            {% block form_inner %}
                {{ form|crispy }}
            {% endblock %}

            {% block form_actions %}
                <div class="form-actions">
                    {% block form_actions_inner %}
                        <input type="submit" class="button" value="{% trans "Reset" %}">
                    {% endblock form_actions_inner %}
                </div>
            {% endblock form_actions %}
        </form>
    {% endblock form %}
{% endblock content %}
