{% extends "registration/base.html" %}

{% load crispy_forms_tags %}
{% load i18n %}
{% load url from future %}


{% block title %}{% trans "Password Change" %}{% endblock title %}

{% block page_main_title %}{% trans "Password Change" %}{% endblock page_main_title %}

{% block content %}
    <p>{% trans "Please enter your old password, for security's sake, and then enter your new password twice so we can verify you typed it in correctly." %}</p>

    {% block form %}
        <form class="{% block form_class %}{% endblock form_class %}" action="" method="post">
            {% csrf_token %}

            {% block form_inner %}
                {{ form|crispy }}
            {% endblock %}

            {% block form_actions %}
                <div class="form-actions">
                    {% block form_actions_inner %}
                        <input type="submit" class="button" value="{% trans "Change my password" %}">
                    {% endblock form_actions_inner %}
                </div>
            {% endblock form_actions %}
        </form>
    {% endblock %}
{% endblock content %}
